👋 Welcome to XGrammar
======================

`GitHub <https://github.com/mlc-ai/xgrammar>`_



XGrammar is open-source solution for flexible, portable, and fast structured generations.
The mission of this project is to bring flexible zero-overhead structure generation everywhere.

Quick Start
-----------

Check out :ref:`quick-start` for quick start examples of using XGrammar.


.. toctree::
   :maxdepth: 1
   :caption: Get Started
   :hidden:

   start/install.rst
   start/quick_start.rst

.. toctree::
   :maxdepth: 1
   :caption: How To
   :hidden:

   how_to/json_generation.rst
   how_to/ebnf_guided_generation.rst
   how_to/engine_integration.rst
   how_to/portable_api.rst
   .. tutorials/web_sdk.rst              .. TODO


.. toctree::
   :maxdepth: 1
   :caption: API Reference
   :hidden:

   api/python/index
